"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filepath = filepath;
exports.sendFile = sendFile;
exports.fileExists = fileExists;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * Serve Karo
 *
 * Static web server
 *
 * Author:  Anshul Kharbanda
 * Created: 4 - 24 - 2017
 */

/**
 * Returns http content type for file extension
 *
 * @param {string} ext file extension
 *
 * @return {string} http content type
 */
function contentTypeForExtension(ext) {
  switch (ext) {
    case '.html':
      return 'text/html';

    case '.css':
      return 'text/css';

    case '.js':
      return 'application/javascript';

    default:
      return 'text/plain';
  }
}
/**
 * Returns the filepath including serving dir given the url and config
 *
 * @param {object} config servekaro config
 * @param {String} url the url from the request
 *
 * @return the filepath including serving dir
 */


function filepath(config, url) {
  var file = url === '/' ? config.root : url;
  return _path["default"].join(config.serving, file);
}
/**
 * Writes file given by url to response according to config
 *
 * @param {object} config servekaro config object
 * @param {String} url url from request
 * @param {ServerResponse} response response object
 * @param {number} status optional status to send (default: 200)
 */


function sendFile(config, url, response) {
  var status = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 200;
  var filename = filepath(config, url);
  var contentType = contentTypeForExtension(_path["default"].extname(filename));
  response.writeHead(status, {
    'Content-Type': contentType
  });

  _fs["default"].createReadStream(filepath(config, url)).pipe(response);
}
/**
 * Check if the file exists and return boolean
 * (since fs.exists is deprecated)
 *
 * @param path {String} the path to check
 * @param callback {Function} callback to responds to exists
 */


function fileExists(path, callback) {
  _fs["default"].stat(path, function (error, stat) {
    // Check error
    if (error) {
        // ENOENT (Error No Entry) indicates file does not exist
        if (error.code === 'ENOENT') callback(null, false); // Other errors are just system errors
        else callback(error, false); // Url exists if stat is file

    } else if (stat.isFile()) callback(null, true); // Else url does not exist
      else callback(null, false);
  });
}
