"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = getHandleNotFoundForConfig;
exports.handleNotFoundObject = handleNotFoundObject;
exports.handleNotFoundString = handleNotFoundString;
exports.handleNotFoundDefault = handleNotFoundDefault;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _files = require("./files");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

/**
 * Return appropriate not found handler for config
 *
 * @param {object} config servekaro config
 *
 * @return {function} not found handler for config
 */
function getHandleNotFoundForConfig(config) {
  switch (_typeof(config.notFound)) {
    case 'string':
      return handleNotFoundString;

    case 'object':
      return handleNotFoundObject;

    default:
      return handleNotFoundDefault;
  }
}
/**
 * Write object not found to response
 *
 * @param {object} config servekaro config
 * @param {ServerResponse} response response object
 */


function handleNotFoundObject(config, response) {
  (0, _files.sendFile)(config, config.notFound.file, response, config.notFound.status);
}
/**
 * Write string not found to response
 *
 * @param {object} config servekaro config
 * @param {ServerResponse} response response object
 */


function handleNotFoundString(config, response) {
  (0, _files.sendFile)(config, config.notFound, response, 404);
}
/**
 * Write default not found to response
 *
 * @param {object} config servekaro config
 * @param {ServerResponse} response response object
 */


function handleNotFoundDefault(config, response) {
  response.writeHead(404, {
    'Content-Type': 'text/plain'
  });
  response.write('File not found!');
  response.end();
}
