"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filepath = filepath;
exports.sendFile = sendFile;
exports.fileExists = fileExists;
exports.filterKeys = filterKeys;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Returns http content type for file extension
 *
 * @param {string} ext file extension
 *
 * @return {string} http content type
 */
function contentTypeForExtension(ext) {
  switch (ext) {
    case '.html':
      return 'text/html';

    case '.css':
      return 'text/css';

    case '.js':
      return 'application/javascript';

    default:
      return 'text/plain';
  }
}
/**
 * Returns the filepath including serving dir given the url and config
 *
 * @param {object} config servekaro config
 * @param {String} url the url from the request
 *
 * @return the filepath including serving dir
 */


function filepath(config, url) {
  var file = url === '/' ? config.root : url;
  return _path["default"].join(config.serving, file);
}
/**
 * Writes file given by url to response according to config
 *
 * @param {object} config servekaro config object
 * @param {String} url url from request
 * @param {ServerResponse} response response object
 * @param {number} status optional status to send (default: 200)
 */


function sendFile(config, url, response) {
  var status = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 200;
  var filename = filepath(config, url);
  var contentType = contentTypeForExtension(_path["default"].extname(filename));
  response.writeHead(status, {
    'Content-Type': contentType
  });

  _fs["default"].createReadStream(filepath(config, url)).pipe(response);
}
/**
 * Check if the file exists and return boolean
 * (since fs.exists is deprecated)
 *
 * @param path {String} the path to check
 * @param callback {Function} callback to responds to exists
 */


function fileExists(path, callback) {
  _fs["default"].stat(path, function (error, stat) {
    // Check error
    if (error) {
        // ENOENT (Error No Entry) indicates file does not exist
        if (error.code === 'ENOENT') callback(null, false); // Other errors are just system errors
        else callback(error, false); // Url exists if stat is file

    } else if (stat.isFile()) callback(null, true); // Else url does not exist
      else callback(null, false);
  });
}
/**
 * Filters the given keys out of the given object
 *
 * @param object the object to filter
 * @param keys the keys to filter out
 *
 * @return the filtered object
 */


function filterKeys(object, keys) {
  return Object.entries(object) // Filter out keys
  .filter(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    return keys.includes(key);
  }) // Map arrays to object entry
  .map(function (_ref3) {
    var _ref4 = _slicedToArray(_ref3, 2),
        key = _ref4[0],
        value = _ref4[1];

    return _defineProperty({}, key, value);
  }) // Reduce object entries into single object
  .reduce(function (obj, entry) {
    return Object.assign(obj, entry);
  }, {});
}
