"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = buildRequestHandler;
exports.handleRequest = handleRequest;
exports.handleError = handleError;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _handleNotFound = _interopRequireDefault(require("./handle-not-found"));

var _files = require("./files");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 * Serve Karo
 *
 * Static web server
 *
 * Author:  Anshul Kharbanda
 * Created: 4 - 24 - 2017
 */

/**
 * Build request handler from config
 *
 * @param {object} config servekaro config
 *
 * @return {function} request handler
 */
function buildRequestHandler(config) {
  var handleNotFound = (0, _handleNotFound["default"])(config);
  return function (request, response) {
    handleRequest(config, request, response, handleNotFound);
  };
}
/**
 * Handle request for url and config object
 *
 * @param {object} config servekaro config
 * @param {ClientRequest} request request object
 * @param {ServerResponse} response response object
 * @param {function} handleNotFound handler for file not found
 */


function handleRequest(config, request, response, handleNotFound) {
  try {
    var fpath = (0, _files.filepath)(config, request.url);
    (0, _files.fileExists)(fpath, function (error, exists) {
      if (error) handleError(response);else if (exists) (0, _files.sendFile)(config, request.url, response);else handleNotFound(config, response);
    });
  } catch (error) {
    handleError(response);
  }
}
/**
 * Write internal server error to response
 *
 * @param {ServerResponse} response response object
 */


function handleError(response) {
  response.writeHead(500, {
    'Content-Type': 'text/plain'
  });
  response.write('Internal server error!');
  response.end();
}
